# Changelog #

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.2.0] - 2025-01-03 ##

### Added 0.2.0 ###

- py.typed
- Proper documentation

## [0.1.0] - 2024-12-12 ##

### Added 0.1.0 ###

- Configuration for loguru

[//]: # (Header for a release: ## [1.1.0] - 2023-09-01)

[//]: # (Sections: Added / Changed / Deprecated / Removed / Fixed)
